==> patch-3.9.1-ONex-OMS-third-source-PHP5.6.tar.gz: ShopexErp/app/base/lib/hchsafe.php <==
<?php
/**
 * 淘宝御城河
 *
 * @category 
 * @package 
 * @author chenping<chenping@shopex.cn>
 * @version $Id: Z
 */
class base_hchsafe
{
    
    /**
     * 判断是否mq
     *
     * @return void
     * @author 
     **/
    private function is_mq(){
return false;
        if (!defined('MQ_HCHSAFE') || !MQ_HCHSAFE){
            return false;
        } else {
            return true;
        }
    }

    /**
     * 登录日志
     *
     * @return void
     * @author 
     **/
    public function login_log($params)
    {
        kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_login($params);
    }

    /**
     * 风控风险分析
     *
     * @return void
     * @author 
     **/
    public function compute_risk($uname,&$msg)
    {
        $rs = kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_computerisk();

        if ($rs['rsp'] == 'fail') $msg = $rs['msg'];

        return $rs['rsp'] == 'succ' ? true : false;
    }


    /**
     * 订单访问(打印)
     *
     * @return void
     * @author 
     **/
    public function order_log($params)
    {
        kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_orderdata($params);
    }


    /**
     * 订单访问
     *
     * @return void
     * @author 
     **/
    public function sql_log($params)
    {
        kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_sql($params);
    }

    public function order_send_log($orders,$node_id)
    {
        if (!$this->is_mq()) return ;

        $opInfo = kernel::single('ome_func')->getDesktopUser();
        $url = strtolower(base_request::get_schema()) . '://' . base_request::get_host() . base_request::get_request_uri();
        $pushData = array(
            'userId'    => $opInfo['op_name'],
            'userIp'    => base_request::get_remote_addr(),
            'ati'       => $_COOKIE['_ati'] ? $_COOKIE['_ati'] : '',
            // 'topAppKey' => TOP_APP_KEY,
            'appName'   => base_request::get_host(),
            'url'       => $url,
            'tradeIds'  => is_array($orders) ? implode(',',$orders) : $orders,
            'sendTo'    => '',
            // 'time'      => time(),
            'node_id'   => $node_id,
        );

        $config              = $GLOBALS['_MQ_HCHSAFE_CONFIG'];
        $config['routerkey'] = 'tb.ordersend.log';
        $queue_name          = 'tb.ordersend.log';

        $bqq = kernel::single('base_queue_mq');
        $bqq->connect($config, $config['exchange'], $queue_name);
        $flag = $bqq->publish(json_encode($pushData),$config['routerkey']);
        $bqq->disConnect();
    }

    public function order_push_log($params)
    {
        kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_orderpush($params);
    }
}

==> patch-4.1.3-ONex-OMS-third-source-PHP5.6.tar.gz: ShopexErp/app/base/lib/hchsafe.php <==
<?php
/**
 * 淘宝御城河
 *
 * @category 
 * @package 
 * @author chenping<chenping@shopex.cn>
 * @version $Id: Z
 */
class base_hchsafe
{

    /**
     * 登录日志
     *
     * @return void
     * @author 
     **/
    public function login_log($params)
    {
        kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_login($params);
        
        kernel::single('erpapi_router_request')->set('hchsafe','360buy')->hchsafe_login($params);
    }

    /**
     * 风控风险分析
     *
     * @return void
     * @author 
     **/
    public function compute_risk($uname,&$msg)
    {
        $rs = kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_computerisk();

        if ($rs['rsp'] == 'fail') $msg = $rs['msg'];

        return $rs['rsp'] == 'succ' ? true : false;
    }


    /**
     * 订单访问(打印)
     *
     * @return void
     * @author 
     **/
    public function order_log($params)
    {
       
        kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_orderdata($params);
        kernel::single('erpapi_router_request')->set('hchsafe','360buy')->hchsafe_orderdata($params);
    }


    /**
     * 订单访问
     *
     * @return void
     * @author 
     **/
    public function sql_log($params)
    {
        kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_sql($params);
    }

    public function order_push_log($params)
    {
        kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_orderpush($params);
        kernel::single('erpapi_router_request')->set('hchsafe','360buy')->hchsafe_orderpush($params);
    }

    public function isVerifyPassed($params) {
        return kernel::single('erpapi_router_request')->set('hchsafe','taobao')->hchsafe_isVerifyPassed($params);
    }
}
